<template>
    <div class="fullheight">
        <div class="container-top">
            <el-form ref="form" :inline="true" label-width="70px">
                <el-form-item label="日期" label-width="40px">
                    <el-date-picker v-model="dateTime" type="date" value-format="yyyy-MM-dd" format="yyyy/MM/dd"
                        placeholder="选择日期" style="width: 150px">
                    </el-date-picker>
                </el-form-item>
                <el-form-item>
                    <el-button style="margin-left: 50px; color: #ccf2ff" @click="getLifeSchedule" type="primary"
                        icon="el-icon-search">查询</el-button>
                    <el-button type="primary" icon="el-icon-refresh" @click="onClickRefresh"
                        style="color: #ccf2ff">重置</el-button>
                </el-form-item>
            </el-form>
        </div>
        <div class="container-content">
            <div class="container">
                <div class="card-contaienr card1">
                    <div class="title">调度效果</div>
                    <div class="content chart-content">
                        <div id="liquid" class="full"></div>
                        <div class="content-text">
                            <span>
                                累计发电量提升: + <i>{{ totalPowerGeneration.toFixed(2) }}</i> kWh
                            </span>
                            <span>
                                累计发电效率提升: + <i>{{ (totalGenerEfficiency * 100).toFixed(2) }}</i> %
                            </span>
                        </div>
                    </div>
                </div>
                <div class="card-contaienr card2">
                    <div class="title">调度功率</div>
                    <div class="content chart-content">
                        <div id="chartbar" class="full"></div>
                    </div>
                </div>
            </div>
            <div class="container">
                <div class="card-contaienr card3">
                    <div class="title">调度日志</div>
                    <div class="content">
                        <el-table size="mini" ref="htTable" :data="tableData" style="width: 100%" height="100%">
                            <el-table-column align="center" prop="dataTimee" label="计算时间" sortable
                                show-overflow-tooltip>
                            </el-table-column>
                            <el-table-column align="center" prop="fanName" label="机组名称" sortable show-overflow-tooltip>
                            </el-table-column>
                            <el-table-column align="center" prop="statValue" label="调度功率(kW)" sortable
                                show-overflow-tooltip>
                            </el-table-column>
                            <el-table-column align="center" prop="powerGenerEfficiency" label="发电效率提升 (%)" sortable
                                show-overflow-tooltip>
                            </el-table-column>
                        </el-table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</template>

<script>
import { Chart } from '@antv/g2'
import { Liquid } from '@antv/g2plot'
import moment from 'moment' //日期格式化插件
export default {
    name: 'OptimalSchedule', //寿命调度
    data() {
        return {
            dateTime: '',
            yesterday: '',
            tableData: [],
            chartBar: null,
            barData: [],
            liquid: null,
            totalPowerGeneration: 0,
            totalGenerEfficiency: 0,
        }
    },
    created() {
        this.getDateTime()
        this.getLifeSchedule()
    },
    mounted() { },
    methods: {
        onClickRefresh() {
            this.dateTime = this.yesterday
        },
        // 获取前一天日期
        getDateTime() {
            let yesterday = new Date().getTime() - 24 * 60 * 60 * 1000
            let date = new Date(yesterday)
            var year = date.getFullYear()
            var month = date.getMonth() + 1
            var day = date.getDate()
            if (month >= 1 && month <= 9) {
                month = '0' + month
            }
            if (day >= 0 && day <= 9) {
                day = '0' + day
            }
            this.dateTime = year + '-' + month + '-' + day
            this.yesterday = this.dateTime
        },
        getLifeSchedule() {
            let data = this.qs.stringify({ localDate: this.dateTime })
            console.log(data, 'this.qs.stringify({localDate: this.dateTime})')
            let query = {
                url: '${cssc}/biz/jkjc/health/v1/getJsonLifeSchedule',
                method: 'post',
                data: this.qs.stringify({ localDate: this.dateTime }),
                headers: {
                    'Content-type': 'application/x-www-form-urlencoded',
                },
            }
            this.$http.request(query).then((res) => {
                if (res && res.data && res.data.value) {
                    console.log(res.data.value)
                    let realData = res.data.value

                    this.tableData = realData.dispatchLog
                        ? realData.dispatchLog
                        : []
                    this.tableData.forEach((item, index) => {
                        item.statValue = item.statValue.toFixed(2)
                        item.dataTimee = moment(parseInt(item.dataTime)).format(
                            'YYYY-MM-DD HH:mm:ss'
                        )
                        item.key = index
                        item.powerGenerEfficiency = (
                            item.powerGenerEfficiency * 100
                        ).toFixed(2)
                    })

                    realData.dispatchPowerList.forEach((item) => {
                        item.statValue = parseFloat(item.statValue.toFixed(2))
                    })
                    this.barData = realData.dispatchPowerList ? realData.dispatchPowerList : []

                    if (this.chartBar) {
                        this.chartBar.changeData(this.barData)
                    } else {
                        this.initChartbar()
                    }
                    this.totalPowerGeneration = realData.totalPowerGeneration ? realData.totalPowerGeneration : 0
                    this.totalGenerEfficiency = realData.totalGenerEfficiency ? realData.totalGenerEfficiency : 0
                    if (this.liquid) {
                        this.liquid.changeData(this.totalGenerEfficiency)
                    } else {
                        this.initLiquid(this.totalGenerEfficiency)
                    }
                }
            })
        },
        initChartbar() {
            this.chartBar = new Chart({
                container: 'chartbar',
                autoFit: true,
                height: 500,
                forceFit: true,
            })
            this.chartBar.data(this.barData)
            this.chartBar.scale('statValue', {
                nice: true,
                alias: '调度功率 kW',
            })
            this.chartBar.axis('statValue', {
                label: {
                    formatter: (val) => {
                        return val + 'kW'
                    },
                },
                grid: {
                    line: {
                        style: {
                            stroke: '#586377',
                            lineWidth: 1,
                            lineDash: [3, 3],
                        },
                    },
                },
            })
            this.chartBar.option('scrollbar', {
                type: 'horizontal',
                categorySize: 40,
                animate: false,
                style: {
                    thumbColor: '#199FD7', //滚动条背景颜色
                    thumbHighlightColor: '#199FD7',
                },
            })
            this.chartBar.axis('fanName', {
                line: {
                    style: {
                        lineWidth: 1,
                        stroke: '#586377',
                    },
                },
                label: {
                    rotate: 45,
                    offset: 20,
                },
            })
            this.chartBar.tooltip({
                showTitle: true,
                showMarkers: false,
                domStyles: {
                    'g2-tooltip': {
                        background: 'rgba(0,0,0, 0.8)',
                        color: '#d6e0ec',
                    },
                },
            })
            this.chartBar.interaction('element-active')
            this.chartBar.interaction('active-region')

            this.chartBar
                .interval()
                .position('fanName*statValue')
                .style({ fill: 'l(90) 0:#22C3FE 0.5:#199FD7 1:#044879' })

            this.chartBar.render()
        },
        initLiquid(percent) {
            this.liquid = new Liquid('liquid', {
                percent: percent,
                outline: {
                    border: 4,
                    distance: 0,
                },
                wave: {
                    count: 3,
                    length: 40,
                },
                pattern: { type: 'line' },
                statistic: {
                    content: {
                        style: {
                            fill: '#fff',
                        },
                    },
                },
                theme: {
                    styleSheet: {
                        brandColor: '#10c4b5',
                    },
                },
            })
            this.liquid.render()
        },
    },
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables.scss';

.container-content {
    width: 100%;
    height: calc(100% - 52px);
    display: flex;
    justify-content: center;
    align-items: center;
    box-sizing: border-box;
}

.container {
    width: 49.5%;
    height: 100%;
    box-sizing: border-box;
}

.fullheight .container:nth-child(1) {
    margin-right: .5%;
}

.fullheight .container:nth-child(2) {
    margin-left: .5%;
}

.card-contaienr {
    width: 100%;
    height: 100%;
    border: 1px solid #14867d;
    border-top: 0;
    border-radius: 6px;
    background-color: rgba(#134458, 0.3);
    box-sizing: border-box;
}

.card1 {
    height: 45%;
}

.card2 {
    height: calc(55% - 10px);
    margin-top: 10px;
}

.card3 {
    border: 0
}

.title {
    height: 40px;
    line-height: 40px;
    box-sizing: border-box;
    font-size: 14px;
    font-weight: bold;
    padding-left: 12px;
    border-top: 1px solid #14867d;
    border-top-left-radius: 6px;
    border-top-right-radius: 6px;
    background-image: linear-gradient(to right,
            $--light-border,
            $--background-color-secondary-light );
}

.card3 {
    .title {
        border: 0;
        background-image: none;
    }

    border: 0;
}

.content {
    height: calc(100% - 40px);
    width: 100%;
}

.chart-content {
    padding: 20px;
    box-sizing: border-box;
}

.editScroll {
    width: 100%;
    height: 100% !important;
    overflow-x: hidden;

    /deep/ .el-scrollbar__wrap {
        overflow-x: hidden;
    }
}

.full {
    width: 100%;
    height: 100%;
}

.content-text {
    width: 90%;
    margin: -10px auto 0;
    display: flex;
    justify-content: space-between;
    align-items: center;

    span {
        font-size: 14px;
    }

    i {
        font-style: normal;
        font-weight: bold;
        font-size: 16px;
        color: #00ffea
    }

}
</style>
